Module cognitive

Module cognitive 

Cognitive queries: belief revision, gap detection, analogical query, drift detection (queries 12-16).

Structs

AnalogicalParams
Parameters for an analogical query.
Analogy
A single analogy found.
BeliefRevisionParams
Parameters for a belief revision query.
BeliefSnapshot
A single snapshot of a belief at a point in time.
BeliefTimeline
A timeline tracking how a belief evolved over time.
CascadeEffect
The effect of a cascade step (used for export compatibility).
CascadeStep
A single step in a cascade of weakened beliefs.
ContradictedNode
A node that contradicts the hypothesis.
DriftParams
Parameters for drift detection.
DriftReport
Full drift detection report.
Gap
A single detected gap in the knowledge graph.
GapDetectionParams
Parameters for gap detection.
GapReport
Full report from gap detection.
GapSummary
Summary statistics of all detected gaps.
PatternMatch
A structural fingerprint of a subgraph for comparison.
RevisionReport
Full report from a belief revision query.
WeakenedNode
A node whose confidence is weakened by the hypothesis.

Enums

AnalogicalAnchor
What to use as the anchor for an analogical query.
ChangeType
The type of change between consecutive belief snapshots.
GapSeverity
How to sort/rank detected gaps.
GapType
The type of knowledge gap detected.