Hooks for integrating with Claude Code’s session management. These functions are called by Claude Code at key moments.
Structs
- Claude
Hooks - Claude Code integration hooks
Hooks for integrating with Claude Code’s session management. These functions are called by Claude Code at key moments.