Cognitive queries: belief revision, gap detection, analogical query, drift detection (queries 12-16).
Structs
- Analogical
Params - Parameters for an analogical query.
- Analogy
- A single analogy found.
- Belief
Revision Params - Parameters for a belief revision query.
- Belief
Snapshot - A single snapshot of a belief at a point in time.
- Belief
Timeline - A timeline tracking how a belief evolved over time.
- Cascade
Effect - The effect of a cascade step (used for export compatibility).
- Cascade
Step - A single step in a cascade of weakened beliefs.
- Contradicted
Node - A node that contradicts the hypothesis.
- Drift
Params - Parameters for drift detection.
- Drift
Report - Full drift detection report.
- Gap
- A single detected gap in the knowledge graph.
- GapDetection
Params - Parameters for gap detection.
- GapReport
- Full report from gap detection.
- GapSummary
- Summary statistics of all detected gaps.
- Pattern
Match - A structural fingerprint of a subgraph for comparison.
- Revision
Report - Full report from a belief revision query.
- Weakened
Node - A node whose confidence is weakened by the hypothesis.
Enums
- Analogical
Anchor - What to use as the anchor for an analogical query.
- Change
Type - The type of change between consecutive belief snapshots.
- GapSeverity
- How to sort/rank detected gaps.
- GapType
- The type of knowledge gap detected.