#[unsafe(no_mangle)]pub unsafe extern "C" fn amem_graph_node_count(
graph: *mut c_void,
) -> u64Expand description
Get node count.
Safety
The caller must ensure that all pointer arguments are valid and non-null (unless the function explicitly handles null pointers), and that any pointed-to data is valid for the expected type and lifetime.